Struct ResultCacheKey
pub struct ResultCacheKey<'a> {
value: &'a dyn Debug,
}Expand description
A key used for the result cache.
The capabilities of this structure are currently quite limited; all one can
do with safe code is get the &dyn Debug of the test input value. This may
improve in the future, particularly at such a time that specialisation
becomes stable.
Fields
value: &'a dyn DebugImplementations
impl<'a> ResultCacheKey<'a>
impl<'a> ResultCacheKey<'a>
pub fn value_debug(&self) -> &dyn Debug
pub fn value_debug(&self) -> &dyn Debug
Return the test input value as an &dyn Debug.